CarbonAIThemeData class

Inheritance
Annotations

Constructors

CarbonAIThemeData({required Color aiInnerShadow, required Color aiAuraStartSm, required Color aiAuraStart, required Color aiAuraEnd, required Color aiBorderStrong, required Color aiBorderStart, required Color aiBorderEnd, required Color aiDropShadow, required Color aiAuraHoverBackground, required Color aiAuraHoverStart, required Color aiAuraHoverEnd, required Color aiPopoverBackground, required Color aiPopoverShadowOuter01, required Color aiPopoverShadowOuter02, required Color aiSkeletonBackground, required Color aiSkeletonElementBackground, required Color aiOverlay, required Color aiPopoverCaretCenter, required Color aiPopoverCaretBottom, required Color aiPopoverCaretBottomBackgroundActions, required Color aiPopoverCaretBottomBackground})
const

Properties

aiAuraEnd Color
final
aiAuraHoverBackground Color
final
aiAuraHoverEnd Color
final
aiAuraHoverStart Color
final
aiAuraStart Color
final
aiAuraStartSm Color
final
aiBorderEnd Color
final
aiBorderStart Color
final
aiBorderStrong Color
final
aiDropShadow Color
final
aiInnerShadow Color
final
aiOverlay Color
final
aiPopoverBackground Color
final
aiPopoverCaretBottom Color
final
aiPopoverCaretBottomBackground Color
final
aiPopoverCaretBottomBackgroundActions Color
final
aiPopoverCaretCenter Color
final
aiPopoverShadowOuter01 Color
final
aiPopoverShadowOuter02 Color
final
aiSkeletonBackground Color
final
aiSkeletonElementBackground Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? aiInnerShadow, Color? aiAuraStartSm, Color? aiAuraStart, Color? aiAuraEnd, Color? aiBorderStrong, Color? aiBorderStart, Color? aiBorderEnd, Color? aiDropShadow, Color? aiAuraHoverBackground, Color? aiAuraHoverStart, Color? aiAuraHoverEnd, Color? aiPopoverBackground, Color? aiPopoverShadowOuter01, Color? aiPopoverShadowOuter02, Color? aiSkeletonBackground, Color? aiSkeletonElementBackground, Color? aiOverlay, Color? aiPopoverCaretCenter, Color? aiPopoverCaretBottom, Color? aiPopoverCaretBottomBackgroundActions, Color? aiPopoverCaretBottomBackground}) CarbonAIThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CarbonAIThemeData>? other, double t) CarbonAIThemeData
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited