CarbonComboBox<T> class

Carbon Design System combo box with autocomplete and search.

A combo box that follows Carbon Design System specifications with:

  • Autocomplete dropdown with search
  • Sharp corners (zero border radius)
  • Proper Carbon colors and states
  • Filtering capabilities
  • Keyboard navigation (↑ ↓ Enter Escape)

Example:

CarbonComboBox<String>(
  value: selectedValue,
  label: 'Select option',
  items: ['Apple', 'Banana', 'Cherry', 'Date', 'Elderberry']
      .map((value) => CarbonComboBoxItem(
            value: value,
            label: value,
          ))
      .toList(),
  onChanged: (value) {
    setState(() => selectedValue = value);
  },
)
Inheritance

Constructors

CarbonComboBox({Key? key, required T? value, required List<CarbonComboBoxItem<T>> items, required ValueChanged<T?>? onChanged, String? label, String? helperText, String? errorText, bool enabled = true, String? placeholder, bool allowClear = true, ValueChanged<String>? onSearch})
const

Properties

allowClear bool
Whether to allow clearing the selection.
final
enabled bool
Whether the combo box is enabled.
final
errorText String?
Optional error text displayed below the combo box.
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
Optional helper text displayed below the combo box.
final
items List<CarbonComboBoxItem<T>>
The list of items to display in the combo box.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Optional label text displayed above the combo box.
final
onChanged ValueChanged<T?>?
Called when the user selects an item.
final
onSearch ValueChanged<String>?
Called when the user types in the search field.
final
placeholder String?
Placeholder text when no value is selected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
The currently selected value.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CarbonComboBox<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited