CarbonFileUploader class
A Carbon Design System file uploader container.
This is the main container that wraps either a button or drop zone, and displays uploaded file items below.
Example:
CarbonFileUploader(
labelTitle: 'Upload files',
labelDescription: 'Max file size is 500mb',
disabled: false,
child: CarbonFileUploaderButton(
onPressed: () async {
final result = await FilePicker.platform.pickFiles(allowMultiple: true);
// Handle files
},
child: Text('Add files'),
),
items: [
CarbonFileUploaderItem(
filename: 'document.pdf',
state: CarbonFileUploaderItemState.complete,
onDelete: () => removeFile('document.pdf'),
),
],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarbonFileUploader
Constructors
Properties
- child → Widget
-
The button or drop zone child widget.
final
- disabled → bool
-
Whether the file uploader is disabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
Widget> -
List of uploaded file items to display.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelDescription → String?
-
Label description text.
final
- labelTitle → String?
-
Label title text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited