CarbonFileUploaderItem class
A Carbon Design System file uploader item.
Displays an uploaded file with filename, state indicator, and optional delete button.
Example:
CarbonFileUploaderItem(
filename: 'document.pdf',
state: CarbonFileUploaderItemState.complete,
size: CarbonFileUploaderItemSize.medium,
onDelete: () => setState(() => _files.removeAt(index)),
)
// With error state
CarbonFileUploaderItem(
filename: 'invalid-file.exe',
state: CarbonFileUploaderItemState.edit,
invalid: true,
errorSubject: 'Invalid file type',
errorBody: 'Only PDF and DOC files are allowed',
onDelete: () => removeFile(),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CarbonFileUploaderItem
Constructors
- CarbonFileUploaderItem({Key? key, required String filename, CarbonFileUploaderItemState state = CarbonFileUploaderItemState.uploading, CarbonFileUploaderItemSize size = CarbonFileUploaderItemSize.medium, VoidCallback? onDelete, bool invalid = false, String? errorSubject, String? errorBody, String iconDescription = 'Delete this file'})
-
Creates a Carbon file uploader item.
const
Properties
- errorBody → String?
-
Error body/description text.
final
- errorSubject → String?
-
Error subject/title text.
final
- filename → String
-
The name of the file.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconDescription → String
-
Aria label for delete icon button.
final
- invalid → bool
-
Whether the file is invalid.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDelete → VoidCallback?
-
Callback when delete button is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → CarbonFileUploaderItemSize
-
The size of the file item.
final
- state → CarbonFileUploaderItemState
-
The state of the file upload.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited