CarbonSkeletonThemeData class

Inheritance
Annotations

Constructors

CarbonSkeletonThemeData({required Color skeletonBackground, required Color skeletonElement})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skeletonBackground Color
final
skeletonElement Color
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? skeletonBackground, Color? skeletonElement}) CarbonSkeletonThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CarbonSkeletonThemeData>? other, double t) CarbonSkeletonThemeData
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited