CarbonUIShellThemeData class

Theme data for Carbon UI Shell component.

The UI Shell provides the global navigation framework including header, side navigation, and panels.

Inheritance
Annotations

Constructors

CarbonUIShellThemeData({required Color headerBackground, required Color headerBorder, required Color headerText, required Color headerIconPrimary, required Color headerIconSecondary, required Color headerNavItemBackground, required Color headerNavItemBackgroundHover, required Color headerNavItemBackgroundActive, required Color headerNavItemBackgroundSelected, required Color headerNavItemBackgroundSelectedHover, required Color headerNavItemText, required Color headerNavItemTextHover, required Color headerNavItemBorderActive, required Color sideNavBackground, required Color sideNavOverlay, required Color sideNavItemBackground, required Color sideNavItemBackgroundHover, required Color sideNavItemBackgroundActive, required Color sideNavItemText, required Color sideNavItemTextHover, required Color sideNavItemIcon, required Color sideNavItemBorderActive, required Color sideNavDivider, required Color panelBackground, required Color panelBorder})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headerBackground Color
final
headerBorder Color
final
headerIconPrimary Color
final
headerIconSecondary Color
final
headerNavItemBackground Color
final
headerNavItemBackgroundActive Color
final
headerNavItemBackgroundHover Color
final
headerNavItemBackgroundSelected Color
final
headerNavItemBackgroundSelectedHover Color
final
headerNavItemBorderActive Color
final
headerNavItemText Color
final
headerNavItemTextHover Color
final
headerText Color
final
panelBackground Color
final
panelBorder Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sideNavBackground Color
final
sideNavDivider Color
final
sideNavItemBackground Color
final
sideNavItemBackgroundActive Color
final
sideNavItemBackgroundHover Color
final
sideNavItemBorderActive Color
final
sideNavItemIcon Color
final
sideNavItemText Color
final
sideNavItemTextHover Color
final
sideNavOverlay Color
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({Color? headerBackground, Color? headerBorder, Color? headerText, Color? headerIconPrimary, Color? headerIconSecondary, Color? headerNavItemBackground, Color? headerNavItemBackgroundHover, Color? headerNavItemBackgroundActive, Color? headerNavItemBackgroundSelected, Color? headerNavItemBackgroundSelectedHover, Color? headerNavItemText, Color? headerNavItemTextHover, Color? headerNavItemBorderActive, Color? sideNavBackground, Color? sideNavOverlay, Color? sideNavItemBackground, Color? sideNavItemBackgroundHover, Color? sideNavItemBackgroundActive, Color? sideNavItemText, Color? sideNavItemTextHover, Color? sideNavItemIcon, Color? sideNavItemBorderActive, Color? sideNavDivider, Color? panelBackground, Color? panelBorder}) CarbonUIShellThemeData
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant ThemeExtension<CarbonUIShellThemeData>? other, double t) CarbonUIShellThemeData
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited