CarbonAIThemeData class
Constructors
-
CarbonAIThemeData({required Color aiInnerShadow, required Color aiAuraStartSm, required Color aiAuraStart, required Color aiAuraEnd, required Color aiBorderStrong, required Color aiBorderStart, required Color aiBorderEnd, required Color aiDropShadow, required Color aiAuraHoverBackground, required Color aiAuraHoverStart, required Color aiAuraHoverEnd, required Color aiPopoverBackground, required Color aiPopoverShadowOuter01, required Color aiPopoverShadowOuter02, required Color aiSkeletonBackground, required Color aiSkeletonElementBackground, required Color aiOverlay, required Color aiPopoverCaretCenter, required Color aiPopoverCaretBottom, required Color aiPopoverCaretBottomBackgroundActions, required Color aiPopoverCaretBottomBackground})
-
const
Methods
-
copyWith({Color? aiInnerShadow, Color? aiAuraStartSm, Color? aiAuraStart, Color? aiAuraEnd, Color? aiBorderStrong, Color? aiBorderStart, Color? aiBorderEnd, Color? aiDropShadow, Color? aiAuraHoverBackground, Color? aiAuraHoverStart, Color? aiAuraHoverEnd, Color? aiPopoverBackground, Color? aiPopoverShadowOuter01, Color? aiPopoverShadowOuter02, Color? aiSkeletonBackground, Color? aiSkeletonElementBackground, Color? aiOverlay, Color? aiPopoverCaretCenter, Color? aiPopoverCaretBottom, Color? aiPopoverCaretBottomBackgroundActions, Color? aiPopoverCaretBottomBackground})
→ CarbonAIThemeData
-
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(covariant ThemeExtension<CarbonAIThemeData>? other, double t)
→ CarbonAIThemeData
-
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited