CarbonContainedListThemeData class
Contained list theme data for Carbon Design System.
Constructors
Properties
- background → Color
-
Background color for the container.
final
- border → Color
-
Border color.
final
- divider → Color
-
Divider color between items.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackground → Color
-
Header background color.
final
- itemBackground → Color
-
List item background color.
final
- itemBackgroundHover → Color
-
List item background color on hover.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → Color
-
Primary text color.
final
- textSecondary → Color
-
Secondary text color.
final
Methods
-
copyWith(
{Color? background, Color? border, Color? headerBackground, Color? itemBackground, Color? itemBackgroundHover, Color? divider, Color? text, Color? textSecondary}) → CarbonContainedListThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited