CarbonSpacing class
Carbon Design System Layout & Spacing.
Contains spacing constants, container sizes, breakpoints, and icon sizes.
See: https://carbondesignsystem.com/guidelines/spacing/overview/
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- spacing01 → const double
- 2px (0.125rem)
- spacing02 → const double
- 4px (0.25rem)
- spacing03 → const double
- 8px (0.5rem)
- spacing04 → const double
- 12px (0.75rem)
- spacing05 → const double
- 16px (1rem)
- spacing06 → const double
- 24px (1.5rem)
- spacing07 → const double
- 32px (2rem)
- spacing08 → const double
- 40px (2.5rem)
- spacing09 → const double
- 48px (3rem)
- spacing10 → const double
- 64px (4rem)
- spacing11 → const double
- 80px (5rem)
- spacing12 → const double
- 96px (6rem)
- spacing13 → const double
- 160px (10rem)