CarbonToggleTip class
Carbon Design System Toggle Tip.
An interactive tooltip that stays open when clicked. Unlike regular tooltips, toggle tips can contain actions and remain open until explicitly closed.
Example:
CarbonToggleTip(
label: 'Feature Name',
content: Text('This is a helpful description'),
actions: [
TextButton(
onPressed: () {},
child: Text('Learn More'),
),
],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CarbonToggleTip
Constructors
-
CarbonToggleTip({Key? key, String? label, required Widget content, List<
Widget> ? actions, CarbonPopoverAlignment alignment = CarbonPopoverAlignment.top, VoidCallback? onOpen, VoidCallback? onClose, Widget? triggerIcon, String buttonLabel = 'Show information', bool defaultOpen = false, double? maxWidth = 288}) -
const
Properties
-
actions
→ List<
Widget> ? -
Optional action buttons to display below the content.
final
- alignment → CarbonPopoverAlignment
-
The alignment of the toggle tip relative to the button.
final
-
Accessible label for the button.
final
- content → Widget
-
The content to display in the toggle tip.
final
- defaultOpen → bool
-
Whether the toggle tip is initially open.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Optional label text displayed before the toggle button.
final
- maxWidth → double?
-
Maximum width of the toggle tip content.
final
- onClose → VoidCallback?
-
Callback when the toggle tip is closed.
final
- onOpen → VoidCallback?
-
Callback when the toggle tip is opened.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triggerIcon → Widget?
-
Custom trigger icon. Defaults to information icon.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CarbonToggleTip> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited