CarbonToggleTipThemeData class
- Inheritance
-
- Object
- ThemeExtension<
CarbonToggleTipThemeData> - CarbonToggleTipThemeData
- Annotations
Constructors
- CarbonToggleTipThemeData({required Color buttonBackground, required Color buttonBackgroundHover, required Color buttonIcon, required Color contentBackground, required Color contentText, required Color border, required Color caret, required Color actionButtonText, required Color actionButtonTextHover})
-
const
Properties
- actionButtonText → Color
-
final
- actionButtonTextHover → Color
-
final
- border → Color
-
final
-
final
-
final
-
final
- caret → Color
-
final
- contentBackground → Color
-
final
- contentText → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? buttonBackground, Color? buttonBackgroundHover, Color? buttonIcon, Color? contentBackground, Color? contentText, Color? border, Color? caret, Color? actionButtonText, Color? actionButtonTextHover}) → CarbonToggleTipThemeData -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< CarbonToggleTipThemeData> ? other, double t) → CarbonToggleTipThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited