CarbonUIShellThemeData class
Theme data for Carbon UI Shell component.
The UI Shell provides the global navigation framework including header, side navigation, and panels.
- Inheritance
-
- Object
- ThemeExtension<
CarbonUIShellThemeData> - CarbonUIShellThemeData
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackground → Color
-
final
- headerBorder → Color
-
final
- headerIconPrimary → Color
-
final
- headerIconSecondary → Color
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- headerText → Color
-
final
- panelBackground → Color
-
final
- panelBorder → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? headerBackground, Color? headerBorder, Color? headerText, Color? headerIconPrimary, Color? headerIconSecondary, Color? panelBackground, Color? panelBorder}) → CarbonUIShellThemeData -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< CarbonUIShellThemeData> ? other, double t) → CarbonUIShellThemeData -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited